@@ -2,8 +2,10 @@ import uuid
 
 import pytest
 import sqlalchemy as sa
+from sqlalchemy.dialects import postgresql
 
 from sqlalchemy_utils import UUIDType
+from sqlalchemy_utils.compat import _select_args
 
 
 @pytest.fixture
@@ -22,7 +24,7 @@ def init_models(User):
     pass
 
 
-class TestUUIDType(object):
+class TestUUIDType:
     def test_repr(self):
         plain = UUIDType()
         assert repr(plain) == 'UUIDType()'
@@ -57,6 +59,16 @@ class TestUUIDType(object):
         assert obj.id.bytes == identifier
 
     def test_compilation(self, User, session):
-        query = sa.select([User.id])
+        query = sa.select(*_select_args(User.id))
+
         # the type should be cacheable and not throw exception
         session.execute(query)
+
+    def test_literal_bind(self, User):
+        expr = (User.id == 'b4e794d6-5750-4844-958c-fa382649719d').compile(
+            dialect=postgresql.dialect(),
+            compile_kwargs={'literal_binds': True}
+        )
+        assert str(expr) == (
+            '''"user".id = \'b4e794d6-5750-4844-958c-fa382649719d\''''
+        )
